# mod_include.pl
# Defines editors SSI directives

sub mod_include_directives
{
$rv = [ [ 'XBitHack', 0, 11, 'virtual directory htaccess' ] ];
return &make_directives($rv, $_[0], "mod_include");
}

sub mod_include_handlers
{
return ("server-parsed");
}

sub edit_XBitHack
{
return (2, "$text{'mod_include_0'}",
        &choice_input($_[0]->{'value'}, "XBitHack", "",
        "$text{'mod_include_1'},off", "$text{'mod_include_2'},on", "$text{'mod_include_3'},full", "$text{'mod_include_4'},"));
}
sub save_XBitHack
{
return &parse_choice("XBitHack", "");
}

1;

